Package 'inqstools'

Title: INQS Tools
Description: This package contains functions and templates I like to use.
Authors: Isaac Quintanilla Salinas [aut, cre] (ORCID: <https://orcid.org/0000-0002-1137-4310>)
Maintainer: Isaac Quintanilla Salinas <[email protected]>
License: CC0
Version: 0.1.2
Built: 2026-05-28 14:46:01 UTC
Source: https://github.com/inqs909/inqstools

Help Index


Title

Description

A wrapper function that will create a learnr interactive document with the CSUCI theme.

Usage

ci_learnr(name)

Arguments

name

A string value containing the name of the tutorial you want to create.

Value

Creates a learnr tutorial with important components to create CI learnr tutorial.